@@ -15,7 +15,8 @@ import configparser
 import pandas as pd
 import time
 import argparse
-from os import path
+from os import path, mkdir
+import time
 
 
 class RobotEnv(Env):
@@ -41,11 +42,13 @@ class RobotEnv(Env):
         self.viewer = None
         self.args = args
         self.reward = 0
+        self.episodes = 1
         self.episode_reward = 0
         self.episode_steps = 0
         self.total_reward = 0
         self.total_steps = 0
         self.success_flag = False
+        self.num_successes = 0
 
         self.done = False
 
@@ -80,7 +83,7 @@ class RobotEnv(Env):
             )
 
     def _configure(self, config: configparser.RawConfigParser) -> None:
-        """Configure the environment using input config file
+        """Configure environment variables using input config object
 
         Args:
             config (configparser.RawConfigParser): input config object
@@ -92,7 +95,7 @@ class RobotEnv(Env):
         self.robot_radius = config.getint("dimensions", "robot_radius")
         self.goal_radius = config.getint("dimensions", "goal_radius")
 
-        self.delta_t = config.getint("timesteps", "delta_t")
+        self.delta_t = config.getfloat("timesteps", "delta_t")
         self.max_episode_steps = config.getint("timesteps", "max_episode_steps")
 
         self.n_angles = config.getint("lidar", "n_angles")
@@ -107,23 +110,24 @@ class RobotEnv(Env):
         self.maximum_distance = config.getfloat("reward", "maximum_distance")
         self.velocity_std = config.getfloat("reward", "velocity_std")
         self.alpha = config.getfloat("reward", "alpha")
+        self.progress_discount = config.getfloat("reward", "progress_discount")
 
         self.render_each = config.getint("render", "render_each")
         self.save_to_file = config.getboolean("render", "save_to_file")
 
         self.epsilon = config.getint("env", "epsilon")
-        
+
         self.collect_statistics = config.getboolean("statistics", "collect_statistics")
         self.scenario = config.get("statistics", "scenario")
 
-    def step(self, action: List):
-        """Step into the new state using an action given by the agent model
+    def step(self, action: List) -> Tuple:
+        """Step into a new state using an action given by the robot model
 
         Args:
-            action (list): velocity action (vx, vy) provided by the agent model
+            action (List): velocity action (vx, vy) provided by the robot model
 
         Returns:
-            dict : environment state as the agent observation
+            Tuple : observation, reward, done, info
         """
         self.reward = 0
         self.episode_steps += 1
@@ -139,38 +143,42 @@ class RobotEnv(Env):
             (self.robot.px, self.robot.py), (self.robot.gx, self.robot.gy)
         )
 
-        self.reward = self.__get_reward() + (
-            old_distance_to_goal - new_distance_to_goal
+        self.reward = (
+            self.__get_reward()
+            + (old_distance_to_goal - new_distance_to_goal) * self.progress_discount
         )
 
         self.episode_reward += self.reward
+
         if self.episode_steps % self.render_each == 0:
             self.render(save_to_file=self.save_to_file)
+
+        if self.collect_statistics:
+            self.episode_statistics.loc[len(self.episode_statistics)] = [  # type: ignore
+                self.total_steps,
+                self.episode_steps,
+                "robot_env_" + self.scenario,
+                100 if self.detect_collison() else 0,
+                self.robot.reached_destination(),
+                self.total_reward,
+                self.episode_reward,
+                self.reward,
+                time.time(),
+            ]
         # log data
         if self.done:
+            self.num_successes += self.success_flag
             self.results.append(
                 [self.episode_reward, self.episode_steps, self.success_flag]
             )
-            if self.collect_statistics:
-                self.episode_statistics.loc[len(self.episode_statistics)] = [  # type: ignore
-                    self.total_steps,
-                    self.episode_steps,
-                    "robot_env_" + self.scenario,
-                    100 if self.detect_collison() else 0,
-                    self.robot.reached_destination(),
-                    self.total_reward,
-                    self.episode_reward,
-                    self.reward,
-                    time.time(),
-                ]
 
         return self._make_obs(), self.reward, self.done, {}
 
     def __get_reward(self) -> float:
-        """Calculate current reward
+        """Calculates current reward
 
         Returns:
-            float: reward
+            float: current reward value
         """
         reward = 0.0
         if self.detect_collison():
@@ -189,12 +197,13 @@ class RobotEnv(Env):
         if self.episode_steps >= self.max_episode_steps:
             self.done = True
             self.success_flag = False
+            self.episodes += 1
 
         return reward
 
     def set_robot_position(self, px: float, py: float, gx: float, gy: float) -> None:
-        """Initialize robot/goal position
-        Should be called from teacher
+        """Initializes robot and goal positions
+        Should be called from ``teacher``
 
         Args:
             px (float): x_position of robot
@@ -211,6 +220,7 @@ class RobotEnv(Env):
         self.robot.set_goal_position([gx, gy])
 
     def add_boarder_obstacles(self) -> None:
+        """Creates border obstacles to limit the allowable navigation area"""
         # fmt: off
         self.obstacles = Obstacles([
                 SingleObstacle(-self.epsilon, 0, self.epsilon, self.height),  # left obstacle
@@ -219,11 +229,11 @@ class RobotEnv(Env):
                 SingleObstacle(0, self.height, self.width, self.epsilon),  # top obstacle
         ])
 
-    def _make_obs(self):
-        """Create agent observation from environment state and LiDAR
+    def _make_obs(self) -> dict:
+        """Creates robot observation from environment state and LiDAR
 
         Returns:
-            dict: agent observation
+            dict: robot observation
         """
         robot = self.robot
         lidar_pos = np.array([robot.px, robot.py, robot.theta], dtype=np.float32)
@@ -252,14 +262,14 @@ class RobotEnv(Env):
         return {"lidar": self.lidar_scan, "robot": robotstate_obs}
 
     def render(
-        self, close: Any = False, save_to_file: Any = False, show_score: Any = True
-    ):
-        """Render robot and obstacles on an openGL window using gym viewer
+        self, close: bool = False, save_to_file: bool = False, show_score: bool = True
+    ) -> bool:
+        """Renders robot and obstacles on an openGL window using gym viewer
 
         Args:
             close (bool, optional): flag to close the environment window. Defaults to False.
             save_to_file (bool, optional): flag to save render data to a file. Defaults to False.
-            show_score (boo, optional): flag to show reward on window. Defaults to True.
+            show_score (bool, optional): flag to show reward on window. Defaults to True.
 
         Returns:
             bool: flag to check the status of the openGL window
@@ -408,19 +418,20 @@ class RobotEnv(Env):
             self.iteration_label.draw()
             win.flip()
             if save_to_file:
-                pyglet.image.get_buffer_manager().get_color_buffer().save(
-                    path.join(
-                        self.args.env_render_path,
-                        "{:08}.png".format(self.episode_steps),
-                    )
+                save_folder = path.join(self.args.env_render_path, f"{self.episodes}")
+                if not path.isdir(save_folder):
+                    mkdir(save_folder)
+                save_path = path.join(
+                    save_folder, "{:08}.png".format(self.episode_steps)
                 )
+                pyglet.image.get_buffer_manager().get_color_buffer().save(save_path)
             return self.viewer.isopen
 
-    def detect_collison(self):
-        """Detect if the agent has collided with any obstacle
+    def detect_collison(self) -> bool:
+        """Detects if the robot has collided with any obstacles
 
         Returns:
-            bool: flag to check collisions
+            bool: flag to check collisions. Ouputs True if there is collision
         """
         collision_flag = False
         for obstacle in self.obstacles.obstacles_list:
@@ -428,24 +439,24 @@ class RobotEnv(Env):
         return collision_flag
 
     def _convert_action_to_ActionXY_format(self, action: List) -> ActionXY:
-        """Convert action array into action object
+        """Converts action array into action object
 
         Args:
-            action (List): list of velocities given by agent model
+            action (List): list of velocities representing the robot action
 
         Returns:
-            ActionXY: same action by given in object format
+            ActionXY: same action but given in object format
         """
         return ActionXY(action[0], action[1], 0)
 
-    def reset(self):
-        """
-        Reset robot state and generate new obstacles points
+    def reset(self) -> dict:
+        """Resets robot state and generate new obstacles points
+
         Returns:
             dict: observation of the current environment state
         """
         if self.done or self.is_initial_state:
-            print("resting robot env ...")
+            print("reseting robot env ...")
             self.robot.set_position([self.robot_initial_px, self.robot_initial_py])
             self.robot.set_goal_position([self.robot_goal_px, self.robot_goal_py])
             self.total_reward += self.episode_reward
